==> kubernetes-model-flowcontrol-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/LimitedPriorityLevelConfigurationBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LimitedPriorityLevelConfigurationBuilder extends LimitedPriorityLevelConfigurationFluentImpl<LimitedPriorityLevelConfigurationBuilder> implements VisitableBuilder<LimitedPriorityLevelConfiguration,LimitedPriorityLevelConfigurationBuilder>{
  public LimitedPriorityLevelConfigurationBuilder() {
    this(false);
  }
  public LimitedPriorityLevelConfigurationBuilder(Boolean validationEnabled) {
    this(new LimitedPriorityLevelConfiguration(), validationEnabled);
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfigurationFluent<?> fluent) {
    this(fluent, false);
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfigurationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LimitedPriorityLevelConfiguration(), validationEnabled);
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfigurationFluent<?> fluent,LimitedPriorityLevelConfiguration instance) {
    this(fluent, instance, false);
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfigurationFluent<?> fluent,LimitedPriorityLevelConfiguration instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAssuredConcurrencyShares(instance.getAssuredConcurrencyShares()); 
    fluent.withLimitResponse(instance.getLimitResponse()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfiguration instance) {
    this(instance,false);
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfiguration instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAssuredConcurrencyShares(instance.getAssuredConcurrencyShares()); 
    this.withLimitResponse(instance.getLimitResponse()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  LimitedPriorityLevelConfigurationFluent<?> fluent;
  Boolean validationEnabled;
  public LimitedPriorityLevelConfiguration build() {
    LimitedPriorityLevelConfiguration buildable = new LimitedPriorityLevelConfiguration(fluent.getAssuredConcurrencyShares(),fluent.getLimitResponse());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-flowcontrol-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/LimitedPriorityLevelConfigurationBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LimitedPriorityLevelConfigurationBuilder extends LimitedPriorityLevelConfigurationFluentImpl<LimitedPriorityLevelConfigurationBuilder> implements VisitableBuilder<LimitedPriorityLevelConfiguration,LimitedPriorityLevelConfigurationBuilder>{
  public LimitedPriorityLevelConfigurationBuilder() {
    this(false);
  }
  public LimitedPriorityLevelConfigurationBuilder(Boolean validationEnabled) {
    this(new LimitedPriorityLevelConfiguration(), validationEnabled);
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfigurationFluent<?> fluent) {
    this(fluent, false);
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfigurationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LimitedPriorityLevelConfiguration(), validationEnabled);
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfigurationFluent<?> fluent,LimitedPriorityLevelConfiguration instance) {
    this(fluent, instance, false);
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfigurationFluent<?> fluent,LimitedPriorityLevelConfiguration instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAssuredConcurrencyShares(instance.getAssuredConcurrencyShares()); 
    fluent.withBorrowingLimitPercent(instance.getBorrowingLimitPercent()); 
    fluent.withLendablePercent(instance.getLendablePercent()); 
    fluent.withLimitResponse(instance.getLimitResponse()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfiguration instance) {
    this(instance,false);
  }
  public LimitedPriorityLevelConfigurationBuilder(LimitedPriorityLevelConfiguration instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAssuredConcurrencyShares(instance.getAssuredConcurrencyShares()); 
    this.withBorrowingLimitPercent(instance.getBorrowingLimitPercent()); 
    this.withLendablePercent(instance.getLendablePercent()); 
    this.withLimitResponse(instance.getLimitResponse()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  LimitedPriorityLevelConfigurationFluent<?> fluent;
  Boolean validationEnabled;
  public LimitedPriorityLevelConfiguration build() {
    LimitedPriorityLevelConfiguration buildable = new LimitedPriorityLevelConfiguration(fluent.getAssuredConcurrencyShares(),fluent.getBorrowingLimitPercent(),fluent.getLendablePercent(),fluent.getLimitResponse());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
